==> hlw-core-0.0.2-20250612.111451-50-sources.jar: cn/gtmap/hlw/core/dto/sqxx/save/SqxxModelDTO.java <==
package cn.gtmap.hlw.core.dto.sqxx.save;

import lombok.Data;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2023/11/23
 * @description
 */
@Data
public class SqxxModelDTO {
    /**
     * 受理编号
     */
    private String slbh;
    /**
     * 申请号
     */
    private String sqh;
    /**
     * 证书项目ID
     */
    private String xmid;
    /**
     * 申请id
     */
    private String sqid;
    /**
     * 申请类型
     */
    private String sqlx;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 房间号
     */
    private String fwfh;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 单元号
     */
    private String fwdyh;
    /**
     * 抵押房产面积(安徽兼容不动产分页查询数据)
     */
    private Double mj;
    /**
     * 实测建筑面积
     */
    private Double jzmj;
    /**
     * 预测建筑面积
     */
    private Double ycjzmj;
    /**
     * 分摊建筑面积
     */
    private Double ftjzmj;
    /**
     * 套内建筑面积
     */
    private Double tnjzmj;
    /**
     * 分摊土地面积
     */
    private Double fttdmj;
    /**
     * 规划用途
     */
    private String fwyt;
    /**
     * 规划用途代码
     */
    private String ghytdm;
    /**
     * 房屋类型
     */
    private String fwlx;
    /**
     * 房屋性质
     */
    private String fwxz;
    /**
     * 总层数
     */
    private String fwzcs;
    /**
     * 所在层
     */
    private String fwszc;
    /**
     * 物理层数
     */
    private String fwsjc;
    /**
     * 房屋结构代码
     */
    private String fwjg;
    /**
     * 土地所有权人
     */
    private String tdsyqr;
    /**
     * 宗地面积
     */
    private Double zdmj;
    /**
     * 权利性质代码
     */
    private String qlxzdm;
    /**
     * 宗地用途代码
     */
    private String zdytdm;
    /**
     * 房屋id
     */
    private String fwid;
    /**
     * 附记
     */
    private String fj;
    /**
     * 证书类型
     */
    private String zslx;
    /**
     * 证明号
     */
    private String zmh;
    /**
     * 小区名称
     */
    private String xqmc;
    /**
     * 栋号
     */
    private String dh;
    /**
     * 土地信息
     */
    private TdxxDTO fwtdxx;
    /**
     * 定义层数
     */
    private String dycs;
    /**
     * 竣工时间
     */
    private String jgsj;
    /**
     * 区域代码
     */
    private String qydm;
    /** 土地使用起始时间*/
    private String tdsyqssj;

    /** 土地使用结束时间*/
    private String tdsyjssj;
}

==> hlw-core-0.0.2-20251208.032658-175-sources.jar: cn/gtmap/hlw/core/dto/sqxx/save/SqxxModelDTO.java <==
package cn.gtmap.hlw.core.dto.sqxx.save;

import cn.gtmap.hlw.core.dto.sqxx.cqxx.SqxxCqxxFsssxxSaveDTO;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2023/11/23
 * @description
 */
@Data
public class SqxxModelDTO {
    /**
     * 受理编号
     */
    private String slbh;
    /**
     * 申请号
     */
    private String sqh;
    /**
     * 证书项目ID
     */
    private String xmid;
    /**
     * 申请id
     */
    private String sqid;
    /**
     * 申请类型
     */
    private String sqlx;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 房间号
     */
    private String fwfh;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 单元号
     */
    private String fwdyh;
    /**
     * 抵押房产面积(安徽兼容不动产分页查询数据)
     */
    private Double mj;
    /**
     * 实测建筑面积
     */
    private Double jzmj;
    /**
     * 预测建筑面积
     */
    private Double ycjzmj;
    /**
     * 分摊建筑面积
     */
    private Double ftjzmj;
    /**
     * 套内建筑面积
     */
    private Double tnjzmj;
    /**
     * 分摊土地面积
     */
    private Double fttdmj;
    /**
     * 规划用途
     */
    private String fwyt;
    /**
     * 规划用途代码
     */
    private String ghytdm;
    /**
     * 房屋类型
     */
    private String fwlx;
    /**
     * 房屋性质
     */
    private String fwxz;
    /**
     * 总层数
     */
    private String fwzcs;
    /**
     * 所在层
     */
    private String fwszc;
    /**
     * 物理层数
     */
    private String fwsjc;
    /**
     * 房屋结构代码
     */
    private String fwjg;
    /**
     * 土地所有权人
     */
    private String tdsyqr;
    /**
     * 宗地面积
     */
    private Double zdmj;
    /**
     * 权利性质代码
     */
    private String qlxzdm;
    /**
     * 宗地用途代码
     */
    private String zdytdm;
    /**
     * 房屋id
     */
    private String fwid;
    /**
     * 附记
     */
    private String fj;
    /**
     * 证书类型
     */
    private String zslx;
    /**
     * 证明号
     */
    private String zmh;
    /**
     * 小区名称
     */
    private String xqmc;
    /**
     * 栋号
     */
    private String dh;
    /**
     * 土地信息
     */
    private TdxxDTO fwtdxx;
    /**
     * 定义层数
     */
    private String dycs;
    /**
     * 竣工时间
     */
    private String jgsj;
    /**
     * 区域代码
     */
    private String qydm;
    /** 土地使用起始时间*/
    private String tdsyqssj;

    /** 土地使用结束时间*/
    private String tdsyjssj;
    /**
     * 附属设施
     */
    private List<SqxxCqxxFsssxxSaveDTO> fsssxxList;
}
